SystemOrganization addCategory: #LostInMorvanBlog!
SystemOrganization addCategory: 'LostInMorvanBlog-Teapot'!
SystemOrganization addCategory: 'LostInMorvanBlog-Teapot-Tests'!
SystemOrganization addCategory: 'LostInMorvanBlog-Tests'!

TestCase subclass: #TinyBlogTest
	instanceVariableNames: 'blog numberOfPosts additionalEmptyPost category1 category2 numberOfPostsFromCategory1 numberOfPostsFromCategory2 numberOfPostsUnclassified numberOfCategories categoriesClass numberOfCategoriesFromVisiblePosts numberOfVisiblePosts numberOfVisiblePostsUnclassified numberOfNotVisiblePostsUnclassified numberOfCategoriesFromNotVisiblePosts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'LostInMorvanBlog-Tests'!

!TinyBlogTest methodsFor: 'running' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
setUp

	blog := TinyBlog createDemoPosts current.
	
	numberOfPosts := 5.
	numberOfVisiblePosts := 5.
	numberOfVisiblePostsUnclassified := 1.
	numberOfNotVisiblePostsUnclassified := 0.
	
	category1 := 'TinyBlog'.
	category2 := 'Pharo'.
	
	categoriesClass := TinyPost unclassifiedTag class.
	
	numberOfPostsFromCategory1 := 1.
	numberOfPostsFromCategory2 := 3.
	numberOfPostsUnclassified  := 1.
	
	numberOfCategories := 3.
	numberOfCategoriesFromVisiblePosts := 3.
	numberOfCategoriesFromNotVisiblePosts := 0.

	
	additionalEmptyPost := TinyPost new! !

!TinyBlogTest methodsFor: 'running' stamp: 'FrancoisJarriges 5/22/2016 13:44'!
tearDown
	"reset the current blog at the end of the tests"

	TinyBlog reset! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/11/2016 11:40'!
testAddBlogPost

	blog addBlogPost: additionalEmptyPost.
	self assert: blog size equals: numberOfPosts + 1! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
testAllBlogPosts

	| allPosts |
	
	allPosts := blog allBlogPosts.
	self assert: allPosts size equals: numberOfPosts.
	allPosts do: [ :eachPost | 
		self assert: eachPost class == TinyPost]
! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
testAllBlogPostsFromCategory

	| postsFromCategory1 postsFromCategory2 postsUnclassified |

	postsFromCategory1 := blog allBlogPostsFromCategory: category1.
	self assert: postsFromCategory1 size = numberOfPostsFromCategory1.
	postsFromCategory1 do: [ :eachPost | self assert: eachPost class == TinyPost ].
	
	postsFromCategory2 := blog allBlogPostsFromCategory: category2.
	self assert: postsFromCategory2 size = numberOfPostsFromCategory2.
	postsFromCategory2 do: [ :eachPost | self assert: eachPost class == TinyPost ].
	
	postsUnclassified := blog allBlogPostsFromCategory: TinyPost unclassifiedTag.
	self assert: postsUnclassified size = numberOfPostsUnclassified.
	postsUnclassified do: [ :eachPost | self assert: eachPost class == TinyPost ].
	
	! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/18/2016 20:07'!
testAllCategories

	| allCategories |

	allCategories := blog allCategories.
	self assert: allCategories size = numberOfCategories.
	allCategories do: [ :eachCategory | 
		self assert: eachCategory class == categoriesClass ].
	
! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/18/2016 20:07'!
testAllCategoriesFromNotVisibleBlogPosts

	| categoriesFromNotVisiblePosts |

	blog addBlogPost: additionalEmptyPost.
	additionalEmptyPost category: 'only for this test'.
	categoriesFromNotVisiblePosts := blog allCategoriesFromNotVisibleBlogPosts.
	self assert: categoriesFromNotVisiblePosts size = (numberOfCategoriesFromNotVisiblePosts + 1).
	categoriesFromNotVisiblePosts do: [ :eachCategory | 
		self assert: eachCategory class == categoriesClass ].! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/18/2016 20:07'!
testAllCategoriesFromVisibleBlogPosts

	| categoriesFromVisiblePosts |

	categoriesFromVisiblePosts := blog allCategoriesFromVisibleBlogPosts.
	self assert: categoriesFromVisiblePosts size = numberOfCategoriesFromVisiblePosts.
	categoriesFromVisiblePosts do: [ :eachCategory | 
		self assert: eachCategory class == categoriesClass ].! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
testAllNotVisibleBlogPosts

	| notVisiblePosts |
	
	blog addBlogPost: additionalEmptyPost.
	notVisiblePosts := blog allNotVisibleBlogPosts.
	self assert: notVisiblePosts size = (numberOfPosts - numberOfVisiblePosts + 1).
	notVisiblePosts do: [ :eachPost | 
		self assert: eachPost class == TinyPost]
	! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
testAllNotVisibleBlogPostsFromCategory
	
	| notVisiblePostsUnclassified |
	
	blog addBlogPost: additionalEmptyPost.
	notVisiblePostsUnclassified := blog allNotVisibleBlogPostsFromCategory: TinyPost unclassifiedTag.
	self assert: notVisiblePostsUnclassified size = (numberOfNotVisiblePostsUnclassified + 1).
	notVisiblePostsUnclassified do: [ :eachPost | self assert: eachPost class == TinyPost]! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
testAllVisibleBlogPosts

	| visiblePosts |
	
	blog addBlogPost: additionalEmptyPost.
	visiblePosts := blog allVisibleBlogPosts.
	self assert: visiblePosts size = numberOfVisiblePosts.
	visiblePosts do: [ :eachPost | 
		self assert: eachPost class == TinyPost]! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
testAllVisibleBlogPostsFromCategory
	
	| visiblePostsUnclassified |
	
	blog addBlogPost: additionalEmptyPost.
	visiblePostsUnclassified := blog allVisibleBlogPostsFromCategory: TinyPost unclassifiedTag.
	self assert: visiblePostsUnclassified size = numberOfVisiblePostsUnclassified.
	visiblePostsUnclassified do: [ :eachPost | self assert: eachPost class == TinyPost]! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
testCategoryBeNotVisible

	| postsUnclassified visiblePostsUnclassified |
	
	postsUnclassified := blog categoryBeNotVisible: TinyPost unclassifiedTag.
	self assert: postsUnclassified size = numberOfPostsUnclassified.
	postsUnclassified do: [ :eachPost | self assert: eachPost class == TinyPost ].
	visiblePostsUnclassified := blog allVisibleBlogPostsFromCategory: TinyPost unclassifiedTag.
	self assert: visiblePostsUnclassified size = 0.
! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
testCategoryBeVisible
	| postsUnclassified visiblePostsUnclassified |
	
	blog addBlogPost: additionalEmptyPost.
	postsUnclassified := blog categoryBeVisible: TinyPost unclassifiedTag.
	self assert: postsUnclassified size = (numberOfPostsUnclassified + 1).
	postsUnclassified do: [ :eachPost | self assert: eachPost class == TinyPost ].
	visiblePostsUnclassified := blog allVisibleBlogPostsFromCategory: TinyPost unclassifiedTag.
	self assert: visiblePostsUnclassified size = (numberOfVisiblePostsUnclassified + 1).! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
testCategoryRenameFromTo
	
	| postsFromCategory1 postsUnclassified |

	postsUnclassified := blog categoryRenameFrom: TinyPost unclassifiedTag  to: category1.
	self assert: postsUnclassified size = numberOfPostsUnclassified.
	postsUnclassified do: [ :eachPost |  self assert: eachPost class == TinyPost ].
	postsFromCategory1 := blog allBlogPostsFromCategory: category1.
	self assert: postsFromCategory1 size = (numberOfPostsFromCategory1 + numberOfPostsUnclassified)
! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/11/2016 12:34'!
testRemoveAllBlogPosts

	blog removeAllBlogPosts.
	self assert: blog size equals: 0! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/11/2016 16:01'!
testRemoveAllBlogPostsFromCategory


	| postsFromCategory2 |
	
	blog removeAllBlogPostsFromCategory: category2.
	postsFromCategory2 := blog allBlogPostsFromCategory: category2.
	self assert: postsFromCategory2 size = 0.
	self assert: blog allBlogPosts size = (numberOfPosts - numberOfPostsFromCategory2)
! !

!TinyBlogTest methodsFor: 'tests-actions' stamp: 'FrancoisJarriges 5/11/2016 16:43'!
testRemoveBlogPost

	blog addBlogPost: additionalEmptyPost.
	blog removeBlogPost: additionalEmptyPost.
	self assert: blog size equals: numberOfPosts! !

!TinyBlogTest methodsFor: 'tests-accessing' stamp: 'FrancoisJarriges 5/11/2016 10:36'!
testSize
	"verify the blog size after tests setup"

	self assert: blog size equals: numberOfPosts ! !

TestCase subclass: #TinyTeapotWebAppTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'LostInMorvanBlog-Teapot-Tests'!

!TinyTeapotWebAppTest commentStamp: 'FrancoisJarriges 5/22/2016 14:55' prior: 0!
I represents a TestCase for  testing the  TinyBlog  web application using the Teapot framework with a demo blog created by TinyBlog>>createDemoPosts .

The actual test is made by navigating with a web browser from the URI  http://localhost:8081/

The method TinyTeapotWebAppTest>>testTinyTeapotWebApp is used only for initializing the Teapot server with a usable demo blog.
 
As playing with the demo server is no more required the application is shut down by executing the TinyTeapotWebAppTestStop TestCase!

!TinyTeapotWebAppTest methodsFor: 'running' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
setUp

	TinyBlog createDemoPosts.
	TinyTeapotWebApp start! !

!TinyTeapotWebAppTest methodsFor: 'tests-web' stamp: 'FrancoisJarriges 5/22/2016 14:42'!
testTinyTeapotWebApp

	self assert: TinyTeapotWebApp server isNotNil

	! !

TestCase subclass: #TinyTeapotWebAppTestStop
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'LostInMorvanBlog-Teapot-Tests'!

!TinyTeapotWebAppTestStop commentStamp: 'FrancoisJarriges 5/22/2016 14:56' prior: 0!
I represents a TestCase for  testing the  TinyBlog  web application shutdown

(see TinyTeapotWebbAppTest for explanations)!

!TinyTeapotWebAppTestStop methodsFor: 'running' stamp: 'FrancoisJarriges 5/22/2016 14:53'!
testTinyTeapotWebAppStop

	TinyTeapotWebApp stop.

	self assert: TinyTeapotWebApp server isNil
! !

Object subclass: #TinyBlog
	instanceVariableNames: 'posts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'LostInMorvanBlog'!

TinyBlog class
	instanceVariableNames: 'uniqueInstance'!

!TinyBlog commentStamp: 'FrancoisJarriges 5/22/2016 14:46' prior: 0!
I represent a TinyBlog kind of blog (FUN MOOC - Programmation immersive en Pharo)

I provide methods on  the class side to manage a  unique instance of myself 

I provide methods to add and remove posts to myself and manage them through the criterias defined by  their class TinyPost

Public API and Key Messages :

aPost := TinyPost title: 'A title'  text: 'A text'  category: 'A category' .

blog :=  TinyBlog current.		"unique instance of TinyBlog"
blog addBlogPost:  aPost.		"add a post to the blog"
blog removeBlogPost:  aPost. 	"remove a post from the blog"

"Get selected posts in an OrderedCollection of posts :"

allPosts :=  blog allBlogPosts.
postsFromACategory :=	blog allBlogPostsFromCategory:  'A category'.
visiblePosts := blog allVisibleBlogPosts.
notVisiblePosts := blog allVisibleBlogPosts.
visiblePostsFromACategory := blog allVisibleBlogPostsFromCategory:  'A category'.
notVisiblePostsFromACategory := blog allNotVisibleBlogPostsFromCategory: 'A category'.

"Get  an actual Set  of   categories among the selected posts :"

allCategories := blog allCategories.
categoriesFromVisiblePosts := blog allCategoriesFromVisibleBlogPosts.
categoriesFromNotVisiblePosts := blog allCategoriesFromNotVisibleBlogPosts.

"Get the actual number of posts :"

numberOfPosts := blog size.

"Remove a selection of posts from the blog :"

blog removeAllBlogPostsFromCategory: 'A category'.
blog removeAllPosts .

Internal Representation and Key Implementation Points.

    Instance Variables
	posts:	<OrderedCollection>
		
     Class Instance Variables 
	uniqueInstance: 	<TinyBlog>
	
    Implementation Points
	A TinyBlog must be  instanciated through the method #current in order to be managed as a singleton
	A #createDemoPosts method is defined on the class side of TinyBlog to allow the creation of a test blog by TinyBlogTest
	
	
	
	!

TinyBlog class
	instanceVariableNames: 'uniqueInstance'!

!TinyBlog class methodsFor: 'tests' stamp: 'FrancoisJarriges 5/22/2016 13:45'!
createDemoPosts
"TBMBlog createDemoPosts"
	
(self current allBlogPosts size > 0) ifTrue: [ self current removeAllBlogPosts ].

self current

	addBlogPost: ((TinyPost 
		title: 'Welcome in TinyBlog' 
		text: 'TinyBlog is a small blog engine made with Pharo.' 
		category: 'TinyBlog') 
		visible: true);
		
	addBlogPost: ((TinyPost 
		title: 'Report Pharo Sprint' 
		text: 'Friday, June 12 there was a Pharo sprint / Moose dojo. It was a nice event with more than 15 motivated sprinters. With the help of candies, cakes and chocolate, huge work has been done'
		category: 'Pharo') 
		visible: true);
		
	addBlogPost: ((TinyPost 
		title: 'Brick on top of Bloc - Preview' 
		text: 'We are happy to announce the first preview version of Brick, a new widget set created from scratch on top of Bloc. Brick is being developed primarily by Alex Syrel (together with Alain Plantec, Andrei Chis and myself), and the work is sponsored by ESUG. Brick is part of the Glamorous Toolkit effort and will provide the basis for the new versions of the development tools.'
		category: 'Pharo') 
		visible: true);
		
	addBlogPost: ((TinyPost 
		title: 'The sad story of unclassified blog posts'
		text: 'So sad that I can read this.') 
		visible: true);
		
	addBlogPost: ((TinyPost 
		title: 'Working with Pharo on the Raspberry Pi' 
		text: 'Hardware is getting cheaper and many new small devices like the famous Raspberry Pi provide new computation power that was one once only available on regular desktop computers.' 
		category: 'Pharo') 
		visible: true)! !

!TinyBlog class methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/10/2016 13:26'!
current
	"answer the unique instance of the TBMBlog and create it if it doesn't exist yet"
	
	^ uniqueInstance ifNil: [ uniqueInstance := self new ]! !

!TinyBlog class methodsFor: 'initialization' stamp: 'FrancoisJarriges 5/22/2016 15:18'!
initialize
	"reset the TBMBlog instance singleton when TBMBlog class is loaded "
	
	super initialize.
	self reset ! !

TinyBlog initialize!

!TinyBlog class methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/10/2016 10:06'!
reset
	uniqueInstance := nil! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/11/2016 16:44'!
addBlogPost: aTBMPost
	"add the given post to the current blog database"

	posts add: aTBMPost! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/10/2016 11:26'!
allBlogPosts
	"answer the entire posts collection defined in the current blog"

	^ posts! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/10/2016 15:33'!
allBlogPostsFromCategory: aString 
	"answer a selection of all the posts classified in the given category from the current blog"
	
	^ posts select: [ :eachPost | eachPost category = aString ]! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/10/2016 13:11'!
allCategories
	"answer a set of all the posts categories defined in the current blog"
	
	^ (posts collect: [ :eachPost | eachPost category ]) asSet! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/11/2016 16:59'!
allCategoriesFromNotVisibleBlogPosts
	"answer a set of all the categories defined among unvisible posts from the current blog"
	
	^ ((posts select: [ :eachPost | eachPost isVisible not ]) 
		collect: [ :eachNotVisiblePost | eachNotVisiblePost category ]) asSet! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/10/2016 15:34'!
allCategoriesFromVisibleBlogPosts
	"answer a set of all the categories defined among visible posts from the current blog"
	
	^ ((posts select: [ :eachPost | eachPost isVisible ]) 
		collect: [ :eachVisiblePost | eachVisiblePost category ]) asSet! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/10/2016 18:01'!
allNotVisibleBlogPosts
	"answer a selection of all the unvisible posts from the current blog"
	
	^ posts select: [ :eachPost | eachPost isVisible not]! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/11/2016 15:57'!
allNotVisibleBlogPostsFromCategory: aString 
	"answer a selection of all the unvisible posts in the given category from the current blog"
	
	^ posts select: [ :eachPost | (eachPost category = aString) & (eachPost isVisible not) ]! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/10/2016 15:34'!
allVisibleBlogPosts
	"answer a selection of all the visible posts from the current blog"
	
	^ posts select: [ :eachPost | eachPost isVisible ]! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/11/2016 12:28'!
allVisibleBlogPostsFromCategory: aString 
	"answer a selection of all the visible posts in the given category from the current blog"
	
	^ posts select: [ :eachPost | (eachPost category = aString) & (eachPost isVisible) ]! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/11/2016 12:28'!
categoryBeNotVisible: aString 
	"make each post unvisible within the given category identified as aString
	answer a selection of all the posts classified in the given category from the current blog"
	
	| postsFromSelectedCategory |
	
	postsFromSelectedCategory := self allBlogPostsFromCategory: aString.
	postsFromSelectedCategory do: [ :eachPostFromSelectedCategory | eachPostFromSelectedCategory beNotVisible ].
	^ postsFromSelectedCategory! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/11/2016 12:29'!
categoryBeVisible: aString 
	"make each post visible within the given category identified as aString
	answer a selection of all the posts classified in the given category from the current blog"
	
	| postsFromSelectedCategory |
	
	postsFromSelectedCategory := self allBlogPostsFromCategory: aString.
	postsFromSelectedCategory do: [ :eachPostFromSelectedCategory | eachPostFromSelectedCategory beVisible ].
	^ postsFromSelectedCategory! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/13/2016 07:13'!
categoryRenameFrom: oldString to: newString
	"rename the actual category identified as actualString by giving it newString as new name
	answer a selection of all the posts classified in the given category from the current blog"

	| postsFromSelectedCategory |
	
	postsFromSelectedCategory := self allBlogPostsFromCategory: oldString.
	postsFromSelectedCategory do: [ :eachPostFromSelectedCategory | 
		eachPostFromSelectedCategory category: newString ].
	^ postsFromSelectedCategory! !

!TinyBlog methodsFor: 'initialization' stamp: 'FrancoisJarriges 5/10/2016 10:04'!
initialize

	super initialize.
	posts := OrderedCollection new! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/10/2016 15:12'!
removeAllBlogPosts
	"remove all posts by creating a new empty collection for the current blog"

	posts := OrderedCollection new! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/10/2016 15:45'!
removeAllBlogPostsFromCategory: aString
	"remove all the posts classified in the given category from the current blog"

	posts	removeAllSuchThat: [ :eachPost | eachPost category = aString ]! !

!TinyBlog methodsFor: 'actions' stamp: 'FrancoisJarriges 5/11/2016 16:44'!
removeBlogPost: aTBMPost 
	"remove the given post from the current blog database"

	posts remove: aTBMPost! !

!TinyBlog methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/10/2016 10:57'!
size
	"answer the size of the posts collection in the current blog"

	^ posts size! !

Object subclass: #TinyPost
	instanceVariableNames: 'title text date category visible'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'LostInMorvanBlog'!

!TinyPost commentStamp: 'FrancoisJarriges 5/10/2016 14:09' prior: 0!
I represent a post in the Tiny Blog (FUN MOOC - Programmation immersive en Pharo)

I provide methods to create and manage  a post


Public API and Key Messages :

post1 := TBMPost title: 'test post 1'	text: 'created unclassified and unvisible' .
post2 := TBMPost title: 'test post 2'  text: 'created unvisible'  category: 'Testing' .

post1 isUnclassified ifTrue:  [post1 category: 'Testing'] .
post1 isVisible  ifFalse:  [post1 beVisible ] .

post1 beNotVisible; category: self class unclassifiedTag .



Internal Representation and Key Implementation Points.

    Instance Variables
	category:	<String>
	date:		<Date>
	text:		<Text>
	title:		<String>
	visible:		<Boolean>


    Implementation Points!

!TinyPost class methodsFor: 'instance-creation' stamp: 'FrancoisJarriges 5/5/2016 10:47'!
title: aTitle text: aText

	^ self new 
		title: aTitle;
		text: aText;
		yourself ! !

!TinyPost class methodsFor: 'instance-creation' stamp: 'FrancoisJarriges 5/5/2016 10:49'!
title: aTitle text: aText category: aCategory

	^ (self title: aTitle text: aText) 
		category: aCategory;
		yourself ! !

!TinyPost class methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/4/2016 17:08'!
unclassifiedTag

	^ 'Unclassified'! !

!TinyPost methodsFor: 'actions' stamp: 'FrancoisJarriges 5/4/2016 17:04'!
beNotVisible

	self visible: false! !

!TinyPost methodsFor: 'actions' stamp: 'FrancoisJarriges 5/4/2016 17:03'!
beVisible

	self visible: true! !

!TinyPost methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/4/2016 17:01'!
category

	^ category! !

!TinyPost methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/9/2016 08:36'!
category: aString

	category := aString! !

!TinyPost methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/4/2016 17:00'!
date

	^ date! !

!TinyPost methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/9/2016 08:54'!
date: aDate

	date := aDate! !

!TinyPost methodsFor: 'initialization' stamp: 'FrancoisJarriges 5/10/2016 14:11'!
initialize

	super initialize.
	self category: self class unclassifiedTag.
	self date: Date today.
	self beNotVisible ! !

!TinyPost methodsFor: 'testing' stamp: 'FrancoisJarriges 5/5/2016 10:57'!
isUnclassified

	^ self category = self class unclassifiedTag ! !

!TinyPost methodsFor: 'testing' stamp: 'FrancoisJarriges 5/4/2016 17:04'!
isVisible

	^ self visible! !

!TinyPost methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/4/2016 16:59'!
text

	^ text! !

!TinyPost methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/9/2016 08:20'!
text: aText

	text := aText ! !

!TinyPost methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/4/2016 16:58'!
title

	^ title! !

!TinyPost methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/9/2016 08:31'!
title: aString

	title := aString ! !

!TinyPost methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/4/2016 17:01'!
visible

	^ visible! !

!TinyPost methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/5/2016 10:34'!
visible: aBoolean

	visible := aBoolean  ! !

Object subclass: #TinyTeapotWebApp
	instanceVariableNames: 'teapot'
	classVariableNames: 'Server'
	poolDictionaries: ''
	category: 'LostInMorvanBlog-Teapot'!

!TinyTeapotWebApp commentStamp: 'FrancoisJarriges 5/22/2016 14:45' prior: 0!
I provide a web application interface for the TinyBlog by using the Teapot framework  (http://smalltalkhub.com/#!!/~zeroflag/Teapot)

Messages to start and stop this web application:

TinyTeapotWebApp start.
TinyTeapotWebApp stop.

Once started, the application can be accessed through the URI http://localhost:8081/ by a web browser.
 
Internal Representation and Key Implementation Points.

    Instance Variables
	teapot	<Teapot>

    Class Variables 
	Server 	<TinyTeapotWebApp>

    Implementation Points!

!TinyTeapotWebApp class methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/19/2016 12:35'!
server

	^ Server! !

!TinyTeapotWebApp class methodsFor: 'starting/stopping' stamp: 'FrancoisJarriges 5/18/2016 10:19'!
start

	Server ifNil: [ Server := self new start ]! !

!TinyTeapotWebApp class methodsFor: 'starting/stopping' stamp: 'FrancoisJarriges 5/18/2016 10:20'!
stop

	Server ifNotNil: [ Server stop. Server := nil ]! !

!TinyTeapotWebApp methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/22/2016 13:44'!
allCategories

	 ^ TinyBlog current allCategoriesFromVisibleBlogPosts ! !

!TinyTeapotWebApp methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/22/2016 13:44'!
allPosts

	 ^ TinyBlog current allVisibleBlogPosts ! !

!TinyTeapotWebApp methodsFor: 'accessing' stamp: 'FrancoisJarriges 5/22/2016 13:44'!
allPostsForCategory: aCategory

	 ^ TinyBlog current allVisibleBlogPostsFromCategory: aCategory  ! !

!TinyTeapotWebApp methodsFor: 'html' stamp: 'FrancoisJarriges 5/19/2016 12:02'!
allPostsPage

	^ String streamContents: [ :newStream |
		self renderPageHeaderOn: newStream.
		newStream << '<h1><a class="root" href="/">TinyBlog</a></h1>'.
		newStream << ('<p class="category">All categories</p>').
		newStream << '<ul>'.
		self allPosts withIndexDo: [ :aPost :index |
			newStream << '<li>';
				<< ('<a href="/all/', index asString, '">');
				<< aPost title;
				<< '</a></li>' ].
		newStream << '</ul>'.
		self renderPageFooterOn: newStream ]
! !

!TinyTeapotWebApp methodsFor: 'html' stamp: 'FrancoisJarriges 5/18/2016 20:01'!
errorPage

	^ String streamContents: [ :newStream |
		self renderPageHeaderOn: newStream.
		newStream << '<p>Oups, an error occured</p>'.
		self renderPageFooterOn: newStream ]
! !

!TinyTeapotWebApp methodsFor: 'html' stamp: 'FrancoisJarriges 5/19/2016 16:01'!
homePage

	^ String streamContents: [ :newStream |
		self renderPageHeaderOn: newStream.
		newStream << '<h1>TinyBlog</h1>'.
		newStream << ('<p class="category">Categories</p>').
		newStream << '<ul><h3>'.
		self allCategories do: [ :aCategory |
			newStream << '<li>';
				<< ('<a href="/', aCategory, '">');
				<< aCategory;
				<< '</a></li>' ].
		newStream << '<li>';
			<< '<a href="/all">';
			<< 'All';
			<< '</a></li>'.
		newStream << '</h3></ul>'.
		self renderPageFooterOn: newStream ]
! !

!TinyTeapotWebApp methodsFor: 'initialization' stamp: 'FrancoisJarriges 5/18/2016 07:35'!
initialize
	
	super initialize.
	teapot := Teapot configure: { 
		#port -> 8081.
		#debugMode -> true }.! !

!TinyTeapotWebApp methodsFor: 'html' stamp: 'FrancoisJarriges 5/19/2016 12:02'!
pageForCategoryName: aCategory

	(self allCategories includes: aCategory) ifFalse: [ ^ self errorPage ].
	^ String streamContents: [ :newStream |
		self renderPageHeaderOn: newStream.
		newStream << '<h1><a class="root" href="/">TinyBlog</a></h1>'.
		newStream << ('<p class="category">Category: ', aCategory ,'</p>').
		newStream << '<ul>'.
		(self allPostsForCategory: aCategory) withIndexDo: [ :aPost :index |
			newStream << '<li>';
				<< ('<a href="/', aCategory, '/', index asString, '">');
				<< aPost title;
				<< '</a></li>' ].
		newStream << '</ul>'.
		self renderPageFooterOn: newStream ]! !

!TinyTeapotWebApp methodsFor: 'html' stamp: 'FrancoisJarriges 5/19/2016 12:03'!
pageForPostNumber: aPostNumber

	| currentPost |
	
	(aPostNumber between: 1 and: self allPosts size) ifFalse: [ ^ self errorPage ].
	currentPost := self allPosts at: aPostNumber.
	^ String streamContents: [ :newStream |
		self renderPageHeaderOn: newStream.
		newStream << '<h1><a class="root" href="/">TinyBlog</a></h1>'.
		newStream << ('<p class="category"><a href="/all">All categories</a></p>').
		newStream << ('<p class="date">', currentPost date mmddyyyy, '</p>').
		newStream << ('<h2>', currentPost title, '</h2>').
		newStream << ('<p>', currentPost text, '</p>').
		self renderPageFooterOn: newStream ]! !

!TinyTeapotWebApp methodsFor: 'html' stamp: 'FrancoisJarriges 5/19/2016 12:03'!
pageForPostNumber: aPostNumber inCategory: aCategory

	| currentPost |
	
	(aPostNumber between: 1 and: (self allPostsForCategory: aCategory) size) ifFalse: [ ^ self errorPage ].
	currentPost := (self allPostsForCategory: aCategory) at: aPostNumber.
	^ String streamContents: [ :newStream |
		self renderPageHeaderOn: newStream.
		newStream << '<h1><a class="root" href="/">TinyBlog</a></h1>'.
		newStream << ('<p class="category"> Category: <a href="/', aCategory, '">', currentPost category, '</a></p>').
		newStream << ('<p class="date">', currentPost date mmddyyyy, '</p>').
		newStream << ('<h2>', currentPost title, '</h2>').
		newStream << ('<p>', currentPost text, '</p>').
		self renderPageFooterOn: newStream ]! !

!TinyTeapotWebApp methodsFor: 'html' stamp: 'FrancoisJarriges 5/18/2016 11:10'!
renderPageFooterOn: aStream 

	aStream << '</body></html>'! !

!TinyTeapotWebApp methodsFor: 'html' stamp: 'FrancoisJarriges 5/19/2016 15:07'!
renderPageHeaderOn: aStream 
	aStream << '
		<!!DOCTYPE html>
		<html>
		<head>
		<style>
			body { 
			   font-family: Arial, Helvetica, sans-serif;
				color: white;
				background-color: #181818; 
			}
			h1 { 
				font-family: "Arial Black", Gadget, sans-serif;
			}
			a { 
				color: orange;
				text-decoration: none;
			}
			a.root { 
				color: white;
			}
			p {
    			border: 1px solid white;
    			padding: 30px;
			}
			p.date { 
				border: 0;
				padding-left: 0;
				padding-bottom: 0;
			}
			p.category { 
				border: 0;
				padding: 10px;
				background-color: black;
			}
		</style>
		</head>
		<body>'! !

!TinyTeapotWebApp methodsFor: 'starting/stopping' stamp: 'FrancoisJarriges 5/19/2016 12:34'!
start
	
	teapot
		GET: '/' -> [ self homePage ];
		GET: '/all' -> [ self allPostsPage ];
		GET: '/all/<id>' -> [ :request |
			self pageForPostNumber: (request at: #id) asNumber ];
		GET: '/<name>' -> [ :request |
			self pageForCategoryName: (request at: #name) ];
		GET: '/<name>/<id>' -> [  :request |
			self pageForPostNumber: (request at: #id) asNumber inCategory: (request at: #name) ];
		start! !

!TinyTeapotWebApp methodsFor: 'starting/stopping' stamp: 'FrancoisJarriges 5/18/2016 10:15'!
stop
	
	teapot stop
! !

TinyBlog initialize!
